@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2014, 2018, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2014, 2020, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -75,8 +75,6 @@
  * @since 9
  */
 module java.base {
-    // source file: file:///build/java11-openjdk/src/jdk11u-jdk-11.0.5+10/src/java.base/share/classes/module-info.java
-    //              file:///build/java11-openjdk/src/jdk11u-jdk-11.0.5+10/src/java.base/unix/classes/module-info.java.extra
     exports java.io;
     exports java.lang;
     exports java.lang.annotation;
@@ -128,6 +126,7 @@ module java.base {
     exports javax.security.auth.spi;
     exports javax.security.auth.x500;
     exports javax.security.cert;
+    exports com.sun.crypto.provider to jdk.crypto.cryptoki;
     exports com.sun.security.ntlm to java.security.sasl;
     exports jdk.internal to jdk.jfr;
     exports jdk.internal.event to jdk.jfr;
@@ -138,7 +137,8 @@ module java.base {
         jdk.jlink;
     exports jdk.internal.loader to
         java.instrument,
-        java.logging;
+        java.logging,
+        java.naming;
     exports jdk.internal.logger to java.logging;
     exports jdk.internal.misc to
         java.desktop,
@@ -153,7 +153,9 @@ module java.base {
         jdk.attach,
         jdk.charsets,
         jdk.compiler,
+        jdk.crypto.cryptoki,
         jdk.internal.vm.ci,
+        jdk.jartool,
         jdk.jfr,
         jdk.jlink,
         jdk.jshell,
@@ -188,6 +190,7 @@ module java.base {
         java.management,
         jdk.internal.jvmstat,
         jdk.management.agent;
+    exports jdk.internal.platform to jdk.management;
     exports jdk.internal.ref to
         java.desktop,
         jdk.unsupported;
@@ -260,7 +263,9 @@ module java.base {
         java.security.jgss,
         jdk.crypto.cryptoki,
         jdk.security.auth;
-    exports sun.security.provider.certpath to java.naming;
+    exports sun.security.provider.certpath to
+        java.naming,
+        jdk.jartool;
     exports sun.security.rsa to jdk.crypto.cryptoki;
     exports sun.security.ssl to java.security.jgss;
     exports sun.security.timestamp to jdk.jartool;
@@ -276,6 +281,7 @@ module java.base {
         jdk.crypto.cryptoki,
         jdk.crypto.ec,
         jdk.jartool,
+        jdk.naming.ldap,
         jdk.security.auth,
         jdk.security.jgss;
     exports sun.security.util.math to jdk.crypto.ec;
